==> haskell-status-notifier-item-0.3.1.0-127-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-2pxYve3cEdPB40h5uajlWv
key:                  status-notifier-item-0.3.1.0-2pxYve3cEdPB40h5uajlWv
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  ac4edf65ad620860617ef21f6803f3fe
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.2.8/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-2pxYve3cEdPB40h5uajlWv
depends:
    base-4.16.4.0 byte-order-0.1.3.1-HRG8PIiNXqjKW6jRXrfBoc
    bytestring-0.11.4.0
    bytestring-to-vector-0.3.0.1-DVr4pJvuu08EzFHnWL2qGd
    containers-0.6.5.1 dbus-1.3.1-DHCfUfF4oE79LQSK3RXSw5
    filepath-1.4.2.2 hslogger-1.3.1.0-FNx7g1zPce93Ck4eeOXymn
    lens-5.2.3-Lr9JV2q3Rgv6Xn7f42cFjs template-haskell-2.18.0.0
    text-1.2.5.0 transformers-0.5.6.2
    vector-0.13.1.0-HyaXkpW7aOFHhHqdwTfvZq

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-status-notifier-item-0.3.1.0-148-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-JFop0ZswEpJA3cUZBblmHS
key:                  status-notifier-item-0.3.1.0-JFop0ZswEpJA3cUZBblmHS
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  e2910710f6a1f93cf428acc99b2d4559
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.2.8/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-JFop0ZswEpJA3cUZBblmHS
depends:
    base-4.16.4.0 byte-order-0.1.3.1-FPxAZovSQ7n1DiXsWJQ0gW
    bytestring-0.11.4.0
    bytestring-to-vector-0.3.0.1-KmkRs8LbF9rCcOHsnu5rM4
    containers-0.6.5.1 dbus-1.3.1-LiIJbsXaEdyKrZjHrptIur
    filepath-1.4.2.2 hslogger-1.3.1.1-6ZXyyIUfBbTJX9w1e5IHfN
    lens-5.2.3-JhnKgAx9k76Jin0xTqnLw0 template-haskell-2.18.0.0
    text-1.2.5.0 transformers-0.5.6.2
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
